@@ -621,6 +621,7 @@ static int compressLogFile(char *name, struct logInfo *log, struct stat *sb)
     if (!WIFEXITED(status) || WEXITSTATUS(status)) {
 	message(MESS_ERROR, "failed to compress log %s\n", name);
 	close(inFile);
+	unlink(compressedName);
 	return 1;
     }
 
@@ -943,6 +944,9 @@ static int copyTruncate(char *currLog, char *saveLog, struct stat *sb,
 	if (sparse_copy(fdcurr, fdsave, sb, saveLog, currLog) != 1) {
 		close(fdcurr);
 		close(fdsave);
+		message(MESS_ERROR, "error copying %s to %s: %s\n", currLog,
+				saveLog, strerror(errno));
+		unlink(saveLog);
 		return 1;
 	}
     }
@@ -1133,8 +1137,8 @@ int findNeedRotating(struct logInfo *log, int logNum, int force)
 	if (log->minsize && sb.st_size < log->minsize) {
 	    state->doRotate = 0;
 	    message(MESS_DEBUG, "  log does not need rotating "
-		    "('misinze' directive is used and the log "
-		    "size is smaller than the minsize value");
+		    "('minsize' directive is used and the log "
+		    "size is smaller than the minsize value)");
 	}
     }
     else if (!state->doRotate) {
@@ -1557,7 +1561,7 @@ int prerotateSingleLog(struct logInfo *log, int logNum, struct logState *state,
 			message(MESS_FATAL, "could not allocate destFile memory\n");
 		}
 		if (!stat(destFile, &fst_buf)) {
-			message(MESS_DEBUG,
+			message(MESS_ERROR,
 					"destination %s already exists, skipping rotation\n",
 					rotNames->firstRotated);
 			hasErrors = 1;
@@ -1781,10 +1785,11 @@ int postrotateSingleLog(struct logInfo *log, int logNum, struct logState *state,
 {
     int hasErrors = 0;
 
-    if (!state->doRotate)
+    if (!state->doRotate) {
 	return 0;
+    }
 
-	if (!hasErrors && log->flags & LOG_FLAG_TMPFILENAME) {
+    if (!hasErrors && log->flags & LOG_FLAG_TMPFILENAME) {
 		char *tmpFilename = NULL;
 		if (asprintf(&tmpFilename, "%s%s", log->files[logNum], ".tmp") < 0) {
 			message(MESS_FATAL, "could not allocate tmpFilename memory\n");
@@ -1821,7 +1826,7 @@ int postrotateSingleLog(struct logInfo *log, int logNum, struct logState *state,
 	hasErrors = removeLogFile(rotNames->disposeName, log);
 
 #ifdef WITH_SELINUX
-	if (selinux_enabled) {
+    if (selinux_enabled) {
 		setfscreatecon_raw(prev_context);
 		freecon(prev_context);
 		prev_context = NULL;
